@@ -1,9 +1,9 @@
 #include "Particle.h"
 
-struct Particle initiate_Particle(const double & log_prob, const int & horizon, const struct Particle * ancestor, const int & anomaly_type, const int & anomaly_comp, const double & strength)
+Particle initiate_Particle(const double & log_prob, const int & horizon, Particle * ancestor, const int & anomaly_type, const int & anomaly_comp, const double & strength)
 {
 	
-	struct Particle out;
+	Particle out;
 
 	out.log_prob = log_prob;
 
